/*
 * Run a script accessing a filesystem.
 *
 * Copyright (C) 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <string.h>

#include "input.h"
#include "ops.h"



/* Line buffer size. */

static int BUFSIZE = 4096;

/* Maximum number of arguments in scripts. */

const int MAX_ARGS = 32;



/* Read operations from a script file. */

int run_script(int argc, char *argv[])
{
    FILE *fp;
    char buffer[BUFSIZE];
    struct read_line_state state;
    enum op_results op_result;
    int num_args;
    char *args[MAX_ARGS];
    int i;

    for (i = 0; i < argc; i++)
    {
        fp = fopen(argv[i], "r");

        state.buffer = buffer;
        state.start = buffer;
        state.end = buffer;
        state.buffer_size = BUFSIZE;
        state.remaining = BUFSIZE - 1;

        while (read_line(fp, &state) != NULL)
        {
            parse_line(state.start, state.eolp, &num_args, args, MAX_ARGS);

            if (num_args > 1)
            {
                op_result = run_operation(args[0], num_args - 1, &args[1]);

                if (handle_op_result(args[0], op_result))
                    return 1;
            }

            state.start = state.eolp + 1;
        }

        fclose(fp);
    }

    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
